MyChangeStack class

Constructors

MyChangeStack({int? limit})
Changes to keep track of

Properties

canRedo → bool
Can redo the previous change
no setter
canUndo → bool
Can undo the previous change
no setter
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int?
Limit changes to store in the history
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transState ↔ TransState
getter/setter pair

Methods

add<T>(MyChange<T> change) → void
Add New Change and Clear Redo Stack
clear() → void
Add New Group of Changes and Clear Redo Stack Clear Undo History
clearHistory() → void
Clear Undo History
endTrans() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redo() → void
Redo Previous Undo
startTrans() → void
toString() → String
A string representation of this object.
inherited
undo() → void
Undo Last Change

Operators

operator ==(Object other) → bool
The equality operator.
inherited