FirebaseConfig class

Inheritance

Constructors

FirebaseConfig({String enterprise = 'Demo'})

Properties

apiServerUrl → String
no setterinherited
dbConnInfo ↔ DBConnInfo
getter/setter pairinherited
enterprise → String
finalinherited
googleOAuthCliendId → String
no setterinherited
guestUserId → String
no setterinherited
guestUserPassword → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonMap ↔ Map<String, dynamic>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savePeriod → int
no setterinherited
socketConnInfo ↔ SocketConnInfo
getter/setter pairinherited
storageConnInfo ↔ StorageConnInfo
getter/setter pairinherited

Methods

initConn(Map<String, dynamic> configMap) → void
inherited
loadAsset() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited