StorageConnInfo class

Constructors

StorageConnInfo()

Properties

apiKey ↔ String
getter/setter pair
appId ↔ String
getter/setter pair
bucketId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messagingSenderId ↔ String
getter/setter pair
projectId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageURL ↔ String
getter/setter pair

Methods

fromJson(Map<String, dynamic> json) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited