AbsExModel class

Constructors

AbsExModel({String? pmid, required ExModelType type, required String parent, String? realTimeKey})

Properties

autoSave ↔ bool
getter/setter pair
createTime → DateTime
no setter
hashCode → int
The hash code for this object.
no setterinherited
hashTag ↔ UndoAble<String>
getter/setter pair
isRemoved ↔ UndoAble<bool>
getter/setter pair
mid → String
no setter
order ↔ UndoAble<double>
getter/setter pair
parentMid ↔ UndoAble<String>
getter/setter pair
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
realTimeKey → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → ExModelType
final
updateTime → DateTime
no setter

Methods

copyFrom(AbsExModel src, {String? newMid, String? pMid}) → void
copyTo(AbsExModel target) → void
create() → void
debugText() → String
fromMap(Map<String, dynamic> map) → void
generateCreateTableScript(String? className) → String
isChanged(AbsExModel other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetCreateTime(DateTime time) → void
resetUpdateTime(DateTime time) → void
save() → void
setRealTimeKey(String key) → void
setUpdateTime() → void
toMap() → Map<String, dynamic>
toMapWithMap(Map<String, dynamic> value) → Map<String, dynamic>
toMapWithValue(String name, dynamic value) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
updateFrom(AbsExModel src) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited