Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
createToDB(AbsExModel model)
→ Future<void>
-
-
debugText()
→ String
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
getAllListFromDB()
→ Future<List<AbsExModel>>
-
-
getFromDB(String mid)
→ Future<AbsExModel?>
-
-
getListFromDB(String userId)
→ Future<List<AbsExModel>>
-
-
getModel(String mid)
→ AbsExModel?
-
-
initStream({required Map<String, dynamic> where, required String orderBy, bool descending = true, int? limit})
→ dynamic
-
-
isNameExist(String value, {String name = 'name'})
→ Future<bool>
-
-
makeCopyName(String newName)
→ Future<String>
-
-
newModel(String mid)
→ AbsExModel
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notify()
→ void
-
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
realTimeCallback(String listenerId, String directive, String userId, Map<String, dynamic> dataMap)
→ void
-
-
removeDuplicatesByMid()
→ void
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeToDB(String mid)
→ Future<void>
-
-
setToDB(AbsExModel model, {bool dontRealTime = false})
→ Future<void>
-
-
setToDBByMid(String mid, {bool dontRealTime = false})
→ Future<void>
-
-
streamData({required Widget consumerFunc(List<Map<String, dynamic>> resultList), required Map<String, dynamic> where, required String orderBy, bool descending = true, int? limit})
→ Widget
-
-
streamData2({required dynamic snapshot, required Widget consumerFunc(List<Map<String, dynamic>> resultList)})
→ Widget
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateToDB(String mid, Map<String, dynamic> updateDataMap)
→ Future<void>
-