AbsModel class

Implementers

Constructors

AbsModel({required ObjectType type})

Properties

createTime ↔ String
getter/setter pair
getValueMap → Map<String, dynamic>
no setter
hashCode → int
The hash code for this object.
no setterinherited
mid ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ObjectType
getter/setter pair
updateTime ↔ String
getter/setter pair

Methods

copyFrom(AbsModel src, {String? newMid}) → void
copyTo(AbsModel target) → void
create() → void
debugText() → String
fromMap(Map<String, dynamic> map) → void
getValue(String key) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → void
setValue(String key, dynamic value) → void
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited