FileModel class

Available extensions

Constructors

FileModel({required String id, required String name, required String url, required String thumbnailUrl, required int size, required ContentsType contentType, double? width, double? height})

Properties

contentType ↔ ContentsType
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
id ↔ String
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int
getter/setter pair
thumbnailUrl ↔ String
getter/setter pair
url ↔ String
getter/setter pair
width ↔ double?
getter/setter pair

Methods

fromMap(Map<String, dynamic> map) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDetailString() → String

Available on FileModel, provided by the FileModelExtension extension

toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited