UserModel class

Inheritance
Available extensions

Constructors

UserModel({ObjectType type = ObjectType.user, Map<String, dynamic>? userData, bool logout = false})

Properties

accountSignUpType → AccountSignUpType
no setter
createTime ↔ String
getter/setter pairinherited
email → String
no setter
getValueMap → Map<String, dynamic>
no setterinherited
hasGenPassword → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
imagefile → String
no setter
isGuestUser → bool
no setter
isLoginedUser → bool
no setter
isRemoved → bool
no setter
isSuperUser → bool
no setter
mid ↔ String
getter/setter pairinherited
name → String
no setter
password → String
no setter
phone → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → String
no setter
type ↔ ObjectType
getter/setter pairinherited
updateTime ↔ String
getter/setter pairinherited
userId → String
no setter
userType → String
no setter

Methods

copyFrom(AbsModel src, {String? newMid}) → void
inherited
copyTo(AbsModel target) → void
inherited
create() → void
inherited
debugText() → String
inherited
fromMap(Map<String, dynamic> map) → void
inherited
getValue(String key) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → void
inherited
setValue(String key, dynamic value) → void
inherited
toDetailString() → String

Available on UserModel, provided by the UserModelExtension extension

toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited