AbsStorage class abstract

Implementers

Constructors

AbsStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chunkedRelayUploadFile(String fileName, String fileType, dynamic file, {bool makeThumbnail = false, String usageType = 'content', String? bucketId, void progressCallback(int loaded, int total)?}) → Future<FileModel?>
chunkedUploadFile(String fileName, String fileType, dynamic file, {bool makeThumbnail = false, String usageType = 'content', String? bucketId, void progressCallback(int loaded, int total)?}) → Future<FileModel?>
convertPdf2Image(String filePath) → Future<List<FileModel>?>
convertPpt2Image(String filePath) → Future<List<FileModel>?>
copyFile(String sourceFilePath, {String? bucketId}) → Future<FileModel?>
copyFileFromUrl(String sourceFileUrl, {String? bucketId}) → Future<FileModel?>
createThumbnailFromBinary(String filePath, String fileName, String fileType, Uint8List fileBytes) → Future<String>
createThumbnailFromFile(String filePath, String fileName, String fileType, dynamic file) → Future<String>
deleteFile(String filePath) → Future<bool>
deleteFileFromUrl(String fileUrl) → Future<bool>
downloadFile(String filePath, String saveName, {String? savePath}) → Future<bool>
downloadFileFromUrl(String fileUrl, String saveName, {String? savePath}) → Future<bool>
downloadUrl(String url, String saveName, {int timeout = 1800, void progressCallback(int loaded, int total)?}) → Future<bool>
getFileBytes(String filePath) → Future<Uint8List?>
getFileData(String filePath, {int maxTry = 1}) → Future<FileModel?>
getFileDataFromUrl(String fileUrl) → Future<FileModel?>
getImageUrl(String filePath) → Future<String>
getMultiFileData(List<String> filePaths) → Future<List<FileModel>>
initialize() → Future<void>
isThumbnailExist(String filePath, String fileName) → Future<bool>
moveFile(String sourceFilePath, {String? bucketId}) → Future<FileModel?>
moveFileFromUrl(String sourceFileUrl, {String? bucketId}) → Future<FileModel?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postUploadFile(String fileName, String fileType, dynamic file, {bool makeThumbnail = false, String usageType = 'content', String? bucketId, int timeout = 1800, void progressCallback(int loaded, int total)?}) → Future<FileModel?>
preSignUploadFile(String fileName, String fileType, dynamic file, {bool makeThumbnail = false, String usageType = 'content', String? bucketId, int timeout = 1800, void progressCallback(int loaded, int total)?}) → Future<FileModel?>
setBucket() → Future<void>
toString() → String
A string representation of this object.
inherited
uploadFile(String fileName, String fileType, Uint8List fileBytes, {bool makeThumbnail = false, String usageType = 'content', String? bucketId}) → Future<FileModel?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

fbStorageConn → FirebaseApp?
no setter
sbStorageConn → SupabaseClient?
no setter

Static Methods

setFirebaseApp(FirebaseApp firebaseApp) → void
setSupabaseApp(SupabaseClient supabaseClient) → void